@@ -49,13 +49,8 @@ import static org.apache.avro.Schema.Type.RECORD;
 import static org.apache.avro.Schema.Type.STRING;
 import static org.apache.avro.Schema.Type.UNION;
 import static org.apache.cassandra.spark.utils.ArrayUtils.setOf;
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertSame;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.fail;
 
 public class CqlToAvroSchemaConverterTest
 {
@@ -95,7 +90,7 @@ public class CqlToAvroSchemaConverterTest
         {
             expectedAvroString = new String(IOUtils.toByteArray(inputStream), StandardCharsets.UTF_8);
         }
-        assertEquals(expectedAvroString, avroStringjsonString);
+        assertThat(avroStringjsonString).as("Generated Avro schema should match expected schema").isEqualTo(expectedAvroString);
     }
 
     @Test
@@ -103,13 +98,13 @@ public class CqlToAvroSchemaConverterTest
     {
         String createStmt = decorateTable("CREATE TABLE %s (an int PRIMARY KEY, m map<text, blob>);");
         Schema schema = cqlToAvroSchemaConverter.convert("a", createStmt);
-        assertNotNull(schema.toString(true));
+        assertThat(schema.toString(true)).as("Schema string should not be null").isNotNull();
         Schema nullableMap = schema.getField("m").schema();
         assertNullableArrayBasedMap(nullableMap,
-                                    key -> assertEquals(STRING, key.getType()),
-                                    value -> assertEquals(BYTES, value.getType()));
-        assertEquals("int", readCqlType(schema, "an"));
-        assertEquals("map<text, blob>", readCqlType(schema, "m"));
+                                    key -> assertThat(key.getType()).as("Map key type should be STRING").isEqualTo(STRING),
+                                    value -> assertThat(value.getType()).as("Map value type should be BYTES").isEqualTo(BYTES));
+        assertThat(readCqlType(schema, "an")).as("CQL type for 'an' field").isEqualTo("int");
+        assertThat(readCqlType(schema, "m")).as("CQL type for 'm' field").isEqualTo("map<text, blob>");
     }
 
     @Test
@@ -117,13 +112,13 @@ public class CqlToAvroSchemaConverterTest
     {
         String createStmt = decorateTable("CREATE TABLE %s (an int PRIMARY KEY, m map<int, blob>);");
         Schema schema = cqlToAvroSchemaConverter.convert("a", createStmt);
-        assertNotNull(schema.toString(true));
+        assertThat(schema.toString(true)).as("Schema string should not be null").isNotNull();
         Schema arrayBasedMap = schema.getField("m").schema();
         assertNullableArrayBasedMap(arrayBasedMap,
-                                    key -> assertEquals(INT, key.getType()),
-                                    value -> assertEquals(BYTES, value.getType()));
-        assertEquals("int", readCqlType(schema, "an"));
-        assertEquals("map<int, blob>", readCqlType(schema, "m"));
+                                    key -> assertThat(key.getType()).as("Map key type should be INT").isEqualTo(INT),
+                                    value -> assertThat(value.getType()).as("Map value type should be BYTES").isEqualTo(BYTES));
+        assertThat(readCqlType(schema, "an")).as("CQL type for 'an' field").isEqualTo("int");
+        assertThat(readCqlType(schema, "m")).as("CQL type for 'm' field").isEqualTo("map<int, blob>");
     }
 
     @Test
@@ -133,58 +128,58 @@ public class CqlToAvroSchemaConverterTest
         final String udt2 = "CREATE TYPE udt_2 (id text, show boolean);";
         String createStmt = decorateTable("CREATE TABLE %s (pk int PRIMARY KEY, c1 udt_1, c2 frozen<list<frozen<udt_2>>>);");
         Schema schema = cqlToAvroSchemaConverter.convert("a", createStmt, setOf(udt1, udt2));
-        assertNotNull(schema.toString(true));
+        assertThat(schema.toString(true)).as("Schema string should not be null").isNotNull();
 
         Schema c1 = schema.getField("c1").schema();
         assertNullable(c1, udt -> {
-            assertEquals(RECORD, udt.getType());
-            assertTrue(AvroSchemas.isRecordBasedUdt(udt));
+            assertThat(udt.getType()).as("UDT type should be RECORD").isEqualTo(RECORD);
+            assertThat(AvroSchemas.isRecordBasedUdt(udt)).as("Should be record-based UDT").isTrue();
 
             Schema ids = udt.getField("ids").schema();
-            assertNotNull(ids);
-            assertTrue(AvroSchemas.isFrozen(ids));
-            assertEquals(ARRAY, ids.getType());
-            assertEquals(STRING, ids.getElementType().getType());
+            assertThat(ids).as("UDT ids field should not be null").isNotNull();
+            assertThat(AvroSchemas.isFrozen(ids)).as("UDT ids field should be frozen").isTrue();
+            assertThat(ids.getType()).as("UDT ids field type should be ARRAY").isEqualTo(ARRAY);
+            assertThat(ids.getElementType().getType()).as("UDT ids element type should be STRING").isEqualTo(STRING);
 
             Schema a = udt.getField("a").schema();
-            assertNotNull(a);
-            assertFalse(AvroSchemas.isFrozen(a));
-            assertEquals(INT, a.getType());
+            assertThat(a).as("UDT a field should not be null").isNotNull();
+            assertThat(AvroSchemas.isFrozen(a)).as("UDT a field should not be frozen").isFalse();
+            assertThat(a.getType()).as("UDT a field type should be INT").isEqualTo(INT);
 
             Schema b = udt.getField("b").schema();
-            assertNotNull(b);
-            assertFalse(AvroSchemas.isFrozen(b));
-            assertEquals(LONG, b.getType());
+            assertThat(b).as("UDT b field should not be null").isNotNull();
+            assertThat(AvroSchemas.isFrozen(b)).as("UDT b field should not be frozen").isFalse();
+            assertThat(b.getType()).as("UDT b field type should be LONG").isEqualTo(LONG);
 
             Schema c = udt.getField("c").schema();
-            assertNotNull(c);
-            assertFalse(AvroSchemas.isFrozen(c));
-            assertEquals(STRING, c.getType());
+            assertThat(c).as("UDT c field should not be null").isNotNull();
+            assertThat(AvroSchemas.isFrozen(c)).as("UDT c field should not be frozen").isFalse();
+            assertThat(c.getType()).as("UDT c field type should be STRING").isEqualTo(STRING);
         });
 
         Schema c2 = schema.getField("c2").schema();
         assertNullable(c2, type -> {
-            assertEquals(ARRAY, type.getType());
-            assertTrue(AvroSchemas.isFrozen(type));
-            assertEquals("frozen<list<frozen<udt_2>>>", AvroSchemas.cqlType(AvroSchemas.unwrapNullable(type)));
+            assertThat(type.getType()).as("c2 type should be ARRAY").isEqualTo(ARRAY);
+            assertThat(AvroSchemas.isFrozen(type)).as("c2 should be frozen").isTrue();
+            assertThat(AvroSchemas.cqlType(AvroSchemas.unwrapNullable(type))).as("c2 CQL type").isEqualTo("frozen<list<frozen<udt_2>>>");
 
             final Schema innerUdt = type.getElementType();
-            assertEquals(RECORD, innerUdt.getType());
-            assertTrue(AvroSchemas.isFrozen(innerUdt));
-            assertEquals("frozen<udt_2>", AvroSchemas.cqlType(AvroSchemas.unwrapNullable(innerUdt)));
+            assertThat(innerUdt.getType()).as("Inner UDT type should be RECORD").isEqualTo(RECORD);
+            assertThat(AvroSchemas.isFrozen(innerUdt)).as("Inner UDT should be frozen").isTrue();
+            assertThat(AvroSchemas.cqlType(AvroSchemas.unwrapNullable(innerUdt))).as("Inner UDT CQL type").isEqualTo("frozen<udt_2>");
 
             Schema id = innerUdt.getField("id").schema();
-            assertNotNull(id);
-            assertEquals(STRING, id.getType());
+            assertThat(id).as("Inner UDT id field should not be null").isNotNull();
+            assertThat(id.getType()).as("Inner UDT id field type should be STRING").isEqualTo(STRING);
 
             Schema show = innerUdt.getField("show").schema();
-            assertNotNull(show);
-            assertEquals(BOOLEAN, show.getType());
+            assertThat(show).as("Inner UDT show field should not be null").isNotNull();
+            assertThat(show.getType()).as("Inner UDT show field type should be BOOLEAN").isEqualTo(BOOLEAN);
         });
 
-        assertEquals("int", readCqlType(schema, "pk"));
-        assertEquals("udt_1", readCqlType(schema, "c1"));
-        assertEquals("frozen<list<frozen<udt_2>>>", readCqlType(schema, "c2"));
+        assertThat(readCqlType(schema, "pk")).as("CQL type for 'pk' field").isEqualTo("int");
+        assertThat(readCqlType(schema, "c1")).as("CQL type for 'c1' field").isEqualTo("udt_1");
+        assertThat(readCqlType(schema, "c2")).as("CQL type for 'c2' field").isEqualTo("frozen<list<frozen<udt_2>>>");
     }
 
     @Test
@@ -192,24 +187,28 @@ public class CqlToAvroSchemaConverterTest
     {
         String createStmt = decorateTable("CREATE TABLE %s (an int PRIMARY KEY, m map<frozen<set<int>>, frozen<map<int, int>>>);");
         Schema schema = cqlToAvroSchemaConverter.convert("a", createStmt);
-        assertNotNull(schema.toString(true));
+        assertThat(schema.toString(true)).as("Schema string should not be null").isNotNull();
 
         Schema arrayBasedMap = schema.getField("m").schema();
         assertNullableArrayBasedMap(arrayBasedMap,
                                     key -> {
-                                        assertEquals(ARRAY, key.getType());
-                                        assertEquals(INT, key.getElementType().getType());
-                                        assertTrue(AvroSchemas.isFrozen(key));
-                                        assertTrue(AvroSchemas.isArrayBasedSet(key));
+                                        assertThat(key.getType()).as("Map key type should be ARRAY").isEqualTo(ARRAY);
+                                        assertThat(key.getElementType().getType()).as("Map key element type should be INT").isEqualTo(INT);
+                                        assertThat(AvroSchemas.isFrozen(key)).as("Map key should be frozen").isTrue();
+                                        assertThat(AvroSchemas.isArrayBasedSet(key)).as("Map key should be array-based set").isTrue();
                                     },
                                     value -> {
-                                        assertTrue(AvroSchemas.isFrozen(value), value.toString());
+                                        assertThat(AvroSchemas.isFrozen(value)).as("Map value should be frozen: " + value).isTrue();
                                         assertArrayBasedMap(value,
-                                                            innerKey -> assertEquals(INT, innerKey.getType()),
-                                                            innerValue -> assertEquals(INT, innerValue.getType()));
+                                                            innerKey -> assertThat(innerKey.getType())
+                                                                        .as("Inner map key type should be INT")
+                                                                        .isEqualTo(INT),
+                                                            innerValue -> assertThat(innerValue.getType())
+                                                                          .as("Inner map value type should be INT")
+                                                                          .isEqualTo(INT));
                                     });
-        assertEquals("int", readCqlType(schema, "an"));
-        assertEquals("map<frozen<set<int>>, frozen<map<int, int>>>", readCqlType(schema, "m"));
+        assertThat(readCqlType(schema, "an")).as("CQL type for 'an' field").isEqualTo("int");
+        assertThat(readCqlType(schema, "m")).as("CQL type for 'm' field").isEqualTo("map<frozen<set<int>>, frozen<map<int, int>>>");
     }
 
     @Test
@@ -217,15 +216,17 @@ public class CqlToAvroSchemaConverterTest
     {
         String createStmt = decorateTable("CREATE TABLE %s (an int PRIMARY KEY, m frozen<map<int, blob>>);");
         Schema schema = cqlToAvroSchemaConverter.convert("a", createStmt);
-        assertNotNull(schema.toString(true));
+        assertThat(schema.toString(true)).as("Schema string should not be null").isNotNull();
         Schema arrayBasedMap = schema.getField("m").schema();
         assertNullableArrayBasedMap(arrayBasedMap,
-                                    arrayMap -> assertTrue(AvroSchemas.isFrozen(arrayMap)),
-                                    key -> assertEquals(INT, key.getType()),
-                                    value -> assertEquals(BYTES, value.getType()));
-        assertTrue(AvroSchemas.isFrozen(AvroSchemas.unwrapNullable(schema.getField("m").schema())));
-        assertEquals("int", readCqlType(schema, "an"));
-        assertEquals("frozen<map<int, blob>>", readCqlType(schema, "m"));
+                                    arrayMap -> assertThat(AvroSchemas.isFrozen(arrayMap)).as("Array map should be frozen").isTrue(),
+                                    key -> assertThat(key.getType()).as("Map key type should be INT").isEqualTo(INT),
+                                    value -> assertThat(value.getType()).as("Map value type should be BYTES").isEqualTo(BYTES));
+        assertThat(AvroSchemas.isFrozen(AvroSchemas.unwrapNullable(schema.getField("m").schema())))
+        .as("Unwrapped schema should be frozen")
+        .isTrue();
+        assertThat(readCqlType(schema, "an")).as("CQL type for 'an' field").isEqualTo("int");
+        assertThat(readCqlType(schema, "m")).as("CQL type for 'm' field").isEqualTo("frozen<map<int, blob>>");
     }
 
     @Test
@@ -233,15 +234,15 @@ public class CqlToAvroSchemaConverterTest
     {
         String createStatement = decorateTable("CREATE TABLE %s (an int PRIMARY KEY, s set<int>);");
         Schema schema = cqlToAvroSchemaConverter.convert("a", createStatement);
-        assertNotNull(schema.toString());
+        assertThat(schema.toString()).as("Schema string should not be null").isNotNull();
         Schema nullableSet = schema.getField("s").schema();
         assertNullable(nullableSet, set -> {
-            assertSame(ARRAY, set.getType());
-            assertEquals(INT, set.getElementType().getType());
-            assertTrue(AvroSchemas.isArrayBasedSet(set));
+            assertThat(set.getType()).as("Set type should be ARRAY").isSameAs(ARRAY);
+            assertThat(set.getElementType().getType()).as("Set element type should be INT").isEqualTo(INT);
+            assertThat(AvroSchemas.isArrayBasedSet(set)).as("Should be array-based set").isTrue();
         });
-        assertEquals("int", readCqlType(schema, "an"));
-        assertEquals("set<int>", readCqlType(schema, "s"));
+        assertThat(readCqlType(schema, "an")).as("CQL type for 'an' field").isEqualTo("int");
+        assertThat(readCqlType(schema, "s")).as("CQL type for 's' field").isEqualTo("set<int>");
     }
 
     @Test
@@ -294,7 +295,7 @@ public class CqlToAvroSchemaConverterTest
         Schema schema1 = cqlToAvroSchemaConverter.convert("test_ks", cqlSchema1);
         String cqlSchema2 = "CREATE TABLE test_ks.test_tbl (a int PRIMARY KEY, b int, c int);";
         Schema schema2 = cqlToAvroSchemaConverter.convert("test_ks", cqlSchema2);
-        assertNotEquals(schema1, schema2);
+        assertThat(schema1).as("Schema1 should not equal schema2 after schema change").isNotEqualTo(schema2);
     }
 
     @Test
@@ -308,11 +309,11 @@ public class CqlToAvroSchemaConverterTest
                 Schema generatedSchema = cqlToAvroSchemaConverter.convert("test_ks", cqlSchema);
                 String[] keyspaceTable = generatedSchema.getNamespace().split("\\.");
                 Schema expectedSchema = LocalTableSchemaStore.getInstance().getSchema(keyspaceTable[0] + '.' + keyspaceTable[1], null);
-                assertEquals(expectedSchema, generatedSchema);
+                assertThat(generatedSchema).as("Generated schema should match expected schema for " + path.getFileName()).isEqualTo(expectedSchema);
             }
             catch (IOException e)
             {
-                fail(e);
+                fail("Schema generation fails", e);
             }
         });
     }
@@ -327,19 +328,21 @@ public class CqlToAvroSchemaConverterTest
                            "    PRIMARY KEY (a, b)\n" +
                            ") WITH CLUSTERING ORDER BY (b DESC)";
         Schema schema = cqlToAvroSchemaConverter.convert("test_ks", cqlSchema);
-        assertEquals("true", schema.getField("b").schema().getTypes().get(0).getProp("isReversed"));
+        assertThat(schema.getField("b").schema().getTypes().get(0).getProp("isReversed"))
+        .as("Field 'b' should be marked as reversed")
+        .isEqualTo("true");
     }
 
     private void testLogicalType(String cqlType, Schema.Type expectedAvroType, LogicalType expectedLogicalType)
     {
         String createStmt = decorateTable("CREATE TABLE %s (id " + cqlType + " PRIMARY KEY, val text);");
         Schema schema = cqlToAvroSchemaConverter.convert("a", createStmt);
-        assertNotNull(schema.toString(true));
+        assertThat(schema.toString(true)).as("Schema string should not be null").isNotNull();
         Schema testFieldSchema = schema.getField("id").schema();
         assertNullable(testFieldSchema, field -> {
-            assertEquals(expectedAvroType, field.getType());
-            assertEquals(expectedLogicalType.getName(), field.getLogicalType().getName());
-            assertEquals(cqlType, AvroSchemas.cqlType(field));
+            assertThat(field.getType()).as("Field type should match expected Avro type").isEqualTo(expectedAvroType);
+            assertThat(field.getLogicalType().getName()).as("Field logical type name should match expected").isEqualTo(expectedLogicalType.getName());
+            assertThat(AvroSchemas.cqlType(field)).as("Field CQL type should match expected").isEqualTo(cqlType);
         });
     }
 
@@ -369,8 +372,8 @@ public class CqlToAvroSchemaConverterTest
 
     private static void assertNullable(Schema nullable, Consumer<Schema> actualTypeVerifier)
     {
-        assertEquals(UNION, nullable.getType());
-        assertEquals(2, nullable.getTypes().size());
+        assertThat(nullable.getType()).as("Nullable schema should be UNION type").isEqualTo(UNION);
+        assertThat(nullable.getTypes().size()).as("Nullable schema should have exactly 2 types").isEqualTo(2);
         boolean hasNull = false;
         for (Schema s : nullable.getTypes())
         {
@@ -383,15 +386,15 @@ public class CqlToAvroSchemaConverterTest
                 actualTypeVerifier.accept(s);
             }
         }
-        assertTrue(hasNull);
+        assertThat(hasNull).as("Nullable schema should contain NULL type").isTrue();
     }
 
     private static void assertArrayBasedMap(Schema arrayBasedMap, Consumer<Schema> keyVerifier, Consumer<Schema> valueVerifier)
     {
-        assertEquals(ARRAY, arrayBasedMap.getType());
-        assertTrue(AvroSchemas.isArrayBasedMap(arrayBasedMap));
+        assertThat(arrayBasedMap.getType()).as("Array-based map should be ARRAY type").isEqualTo(ARRAY);
+        assertThat(AvroSchemas.isArrayBasedMap(arrayBasedMap)).as("Should be array-based map").isTrue();
         Schema keyValue = arrayBasedMap.getElementType();
-        assertEquals(RECORD, keyValue.getType());
+        assertThat(keyValue.getType()).as("Key-value record type should be RECORD").isEqualTo(RECORD);
         keyVerifier.accept(keyValue.getField(AvroConstants.ARRAY_BASED_MAP_KEY_NAME).schema());
         valueVerifier.accept(keyValue.getField(AvroConstants.ARRAY_BASED_MAP_VALUE_NAME).schema());
     }
