@@ -85,8 +85,8 @@ public class BufferingInputStream<T extends CassandraFile> extends InputStream i
     private boolean skipping = false;
     private StreamState state = StreamState.Init;
     private StreamBuffer currentBuffer = null;
-    private int position;
-    private int length;
+    private int position; // position within current buffer
+    private int length; // length of current buffer
 
     /**
      * @param source CassandraFileSource to async provide the bytes after {@link CassandraFileSource#request(long, long, StreamConsumer)} is called
@@ -101,6 +101,22 @@ public class BufferingInputStream<T extends CassandraFile> extends InputStream i
         this.stats = stats;
     }
 
+    public BufferingInputStream(CassandraFileSource<T> source, BufferingInputStreamStats<T> stats, long position)
+    {
+        this(source, stats);
+        this.rangeStart = position;
+        // adjusting bytes read and written so that isFinished() returns correct output and we know
+        // when we reached the end of the stream
+        this.bytesRead = position == 0 ? 0 : (position + 1);
+        this.bytesWritten.set(this.bytesRead);
+    }
+
+    public BufferingInputStream<T> reBuffer(long position)
+    {
+        closeInternal(false);
+        return new BufferingInputStream<>(source, stats, position);
+    }
+
     public long startTimeNanos()
     {
         return startTimeNanos;
@@ -136,6 +152,11 @@ public class BufferingInputStream<T extends CassandraFile> extends InputStream i
         return state == StreamState.Closed;
     }
 
+    public long chunkBufferSize()
+    {
+        return source.chunkBufferSize();
+    }
+
     /**
      * Can request more bytes if:
      * 1. a request not already in-flight
@@ -348,23 +369,27 @@ public class BufferingInputStream<T extends CassandraFile> extends InputStream i
      * @throws EOFException if attempts to read beyond the end of the file
      * @throws IOException  for failure during I/O
      */
-    public void read(ByteBuffer buffer) throws IOException
+    public int read(ByteBuffer buffer) throws IOException
     {
-        for (int remainingLength = buffer.remaining(); 0 < remainingLength; remainingLength = buffer.remaining())
+        int read = 0;
+        int remaining = buffer.remaining();
+        while (read < remaining)
         {
             if (checkState() < 0)
             {
                 throw new EOFException();
             }
-            int readLength = Math.min(length - position, remainingLength);
+            int readLength = Math.min(length - position, buffer.remaining());
             if (0 < readLength)
             {
+                read += readLength;
                 currentBuffer.getBytes(position, buffer, readLength);
                 position += readLength;
                 bytesRead += readLength;
             }
             maybeReleaseBuffer();
         }
+        return read;
     }
 
     public static void ensureOffsetWithinBounds(int offset, int length, int bufferLength)
@@ -428,6 +453,11 @@ public class BufferingInputStream<T extends CassandraFile> extends InputStream i
 
     @Override
     public void close()
+    {
+        closeInternal(true);
+    }
+
+    private void closeInternal(boolean releaseSource)
     {
         if (state == StreamState.Closed)
         {
@@ -441,6 +471,17 @@ public class BufferingInputStream<T extends CassandraFile> extends InputStream i
         closed = true;
         releaseBuffer();
         queue.clear();
+        if (releaseSource)
+        {
+            try
+            {
+                source.close();
+            }
+            catch (Exception e)
+            {
+                // close quietly
+            }
+        }
     }
 
     @Override
