@@ -26,7 +26,6 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Objects;
-import java.util.UUID;
 import java.util.concurrent.TimeUnit;
 import java.util.function.Consumer;
 import java.util.stream.Collectors;
@@ -41,14 +40,16 @@ import o.a.c.sidecar.client.shaded.common.request.data.CreateRestoreJobRequestPa
 import o.a.c.sidecar.client.shaded.common.request.data.UpdateRestoreJobRequestPayload;
 import org.apache.cassandra.spark.bulkwriter.cloudstorage.CloudStorageDataTransferApi;
 import org.apache.cassandra.spark.bulkwriter.cloudstorage.CloudStorageStreamResult;
-import org.apache.cassandra.spark.bulkwriter.cloudstorage.ImportCoordinator;
 import org.apache.cassandra.spark.bulkwriter.cloudstorage.ImportCompletionCoordinator;
+import org.apache.cassandra.spark.bulkwriter.cloudstorage.ImportCoordinator;
+import org.apache.cassandra.spark.bulkwriter.cloudstorage.coordinated.CassandraClusterInfoGroup;
 import org.apache.cassandra.spark.bulkwriter.cloudstorage.coordinated.CoordinatedCloudStorageDataTransferApi;
-import org.apache.cassandra.spark.bulkwriter.cloudstorage.coordinated.CoordinatedWriteConf;
 import org.apache.cassandra.spark.bulkwriter.cloudstorage.coordinated.CoordinatedImportCoordinator;
+import org.apache.cassandra.spark.bulkwriter.cloudstorage.coordinated.CoordinatedWriteConf;
 import org.apache.cassandra.spark.bulkwriter.token.ConsistencyLevel;
 import org.apache.cassandra.spark.bulkwriter.token.MultiClusterReplicaAwareFailureHandler;
 import org.apache.cassandra.spark.bulkwriter.token.ReplicaAwareFailureHandler;
+import org.apache.cassandra.spark.data.partitioner.Partitioner;
 import org.apache.cassandra.spark.exception.SidecarApiCallException;
 import org.apache.cassandra.spark.exception.UnsupportedAnalyticsOperationException;
 import org.apache.cassandra.spark.transports.storage.extensions.StorageTransportConfiguration;
@@ -76,7 +77,7 @@ public class CassandraBulkSourceRelation extends BaseRelation implements Inserta
     private final BulkWriterContext writerContext;
     private final SQLContext sqlContext;
     private final JavaSparkContext sparkContext;
-    private final Broadcast<BulkWriterContext> broadcastContext;
+    private final Broadcast<BulkWriterConfig> broadcastConfig;
     private final BulkWriteValidator writeValidator;
     private final SimpleTaskScheduler simpleTaskScheduler;
     private ImportCoordinator importCoordinator = null; // value is only set when using S3_COMPAT
@@ -88,12 +89,70 @@ public class CassandraBulkSourceRelation extends BaseRelation implements Inserta
         this.writerContext = writerContext;
         this.sqlContext = sqlContext;
         this.sparkContext = JavaSparkContext.fromSparkContext(sqlContext.sparkContext());
-        this.broadcastContext = sparkContext.<BulkWriterContext>broadcast(writerContext);
+        // Extract immutable configuration from the context for broadcasting
+        BulkWriterConfig config = extractConfig(writerContext, sparkContext.defaultParallelism());
+        this.broadcastConfig = sparkContext.<BulkWriterConfig>broadcast(config);
         ReplicaAwareFailureHandler<RingInstance> failureHandler = new MultiClusterReplicaAwareFailureHandler<>(writerContext.cluster().getPartitioner());
         this.writeValidator = new BulkWriteValidator(writerContext, failureHandler);
         this.simpleTaskScheduler = new SimpleTaskScheduler();
     }
 
+    /**
+     * Extracts immutable configuration from a BulkWriterContext for broadcasting.
+     * Creates BroadcastableCluster, BroadcastableJobInfo, and BroadcastableSchemaInfo
+     * to ensure zero transient fields and avoid Logger references in the broadcast object.
+     */
+    private static BulkWriterConfig extractConfig(BulkWriterContext context, int sparkDefaultParallelism)
+    {
+        if (context instanceof AbstractBulkWriterContext)
+        {
+            AbstractBulkWriterContext abstractContext = (AbstractBulkWriterContext) context;
+            ClusterInfo originalClusterInfo = abstractContext.cluster();
+
+            // Create BroadcastableCluster to avoid transient fields in broadcast
+            IBroadcastableClusterInfo broadcastableClusterInfo;
+            if (originalClusterInfo instanceof CassandraClusterInfoGroup)
+            {
+                // Coordinated write scenario
+                @SuppressWarnings("unchecked")
+                CassandraClusterInfoGroup multiCluster = (CassandraClusterInfoGroup) originalClusterInfo;
+                broadcastableClusterInfo = BroadcastableClusterInfoGroup.from(
+                    multiCluster,
+                    abstractContext.bulkSparkConf()
+                );
+            }
+            else
+            {
+                // Single cluster scenario
+                broadcastableClusterInfo = BroadcastableClusterInfo.from(
+                    originalClusterInfo,
+                    abstractContext.bulkSparkConf()
+                );
+            }
+
+            // Create BroadcastableJobInfo to avoid Logger in TokenPartitioner
+            BroadcastableJobInfo broadcastableJobInfo = BroadcastableJobInfo.from(
+                abstractContext.job(),
+                abstractContext.bulkSparkConf()
+            );
+
+            // Create BroadcastableSchemaInfo to avoid Logger in TableSchema
+            BroadcastableSchemaInfo broadcastableSchemaInfo = BroadcastableSchemaInfo.from(
+                abstractContext.schema()
+            );
+
+            return new BulkWriterConfig(
+                abstractContext.bulkSparkConf(),
+                sparkDefaultParallelism,
+                broadcastableJobInfo,
+                broadcastableClusterInfo,
+                broadcastableSchemaInfo,
+                abstractContext.lowestCassandraVersion()
+            );
+        }
+        throw new IllegalArgumentException("Cannot extract config from context type: " + context.getClass().getName());
+    }
+
     @Override
     @NotNull
     public SQLContext sqlContext()
@@ -129,14 +188,15 @@ public class CassandraBulkSourceRelation extends BaseRelation implements Inserta
         this.startTimeNanos = System.nanoTime();
         maybeScheduleTimeout();
         maybeEnableTransportExtension();
-        Tokenizer tokenizer = new Tokenizer(writerContext);
-        TableSchema tableSchema = writerContext.schema().getTableSchema();
+        BroadcastableTableSchema broadcastableTableSchema = broadcastConfig.value().getBroadcastableSchemaInfo().getBroadcastableTableSchema();
+        boolean isMurmur3Partitioner = writerContext.cluster().getPartitioner() == Partitioner.Murmur3Partitioner;
+        Tokenizer tokenizer = new Tokenizer(broadcastableTableSchema, isMurmur3Partitioner);
         JavaPairRDD<DecoratedKey, Object[]> sortedRDD = data.toJavaRDD()
                                                             .map(Row::toSeq)
                                                             .map(seq -> JavaConverters.seqAsJavaListConverter(seq).asJava().toArray())
-                                                            .map(tableSchema::normalize)
+                                                            .map(broadcastableTableSchema::normalize)
                                                             .keyBy(tokenizer::getDecoratedKey)
-                                                            .repartitionAndSortWithinPartitions(broadcastContext.getValue().job().getTokenPartitioner());
+                                                            .repartitionAndSortWithinPartitions(writerContext.job().getTokenPartitioner());
         persist(sortedRDD, data.columns());
     }
 
@@ -181,14 +241,14 @@ public class CassandraBulkSourceRelation extends BaseRelation implements Inserta
 
         try
         {
-            // Copy the broadcast context as a local variable (by passing as the input) to avoid serialization error
+            // Copy the broadcast config as a local variable (by passing as the input) to avoid serialization error
             // W/o this, SerializedLambda captures the CassandraBulkSourceRelation object, which is not serializable (required by Spark),
             // as a captured argument. It causes "Task not serializable" error.
             List<WriteResult> writeResults = sortedRDD
-                                             .mapPartitions(writeRowsInPartition(broadcastContext, columnNames))
+                                             .mapPartitions(writeRowsInPartition(broadcastConfig, columnNames))
                                              .collect();
 
-            // Unpersist broadcast context to free up executors while driver waits for the
+            // Unpersist broadcast config to free up executors while driver waits for the
             // import to complete
             unpersist();
 
@@ -279,7 +339,11 @@ public class CassandraBulkSourceRelation extends BaseRelation implements Inserta
         context.transportExtensionImplementation()
                .onAllObjectsPersisted(objectCount, rowCount, elapsedTimeMillis());
 
-        setSliceCountForRestoreJob(context, objectCount);
+        // only need to set the slice count (for better progress tracking) when in coordinated write mode
+        if (writerContext.job().isCoordinatedWriteEnabled())
+        {
+            setSliceCountForRestoreJob(context, objectCount);
+        }
 
         awaitImportCompletion(context, resultsAsCloudStorageStreamResults);
         markRestoreJobAsSucceeded(context);
@@ -327,15 +391,16 @@ public class CassandraBulkSourceRelation extends BaseRelation implements Inserta
     }
 
     /**
-     * Get a ref copy of BulkWriterContext broadcast variable and compose a function to transform a partition into StreamResult
+     * Get a ref copy of BulkWriterConfig broadcast variable and compose a function to transform a partition into StreamResult
      *
-     * @param ctx BulkWriterContext broadcast variable
+     * @param config      BulkWriterConfig broadcast variable
+     * @param columnNames column names array
      * @return FlatMapFunction
      */
     private static FlatMapFunction<Iterator<Tuple2<DecoratedKey, Object[]>>, WriteResult>
-    writeRowsInPartition(Broadcast<BulkWriterContext> ctx, String[] columnNames)
+    writeRowsInPartition(Broadcast<BulkWriterConfig> config, String[] columnNames)
     {
-        return iterator -> Collections.singleton(new RecordWriter(ctx.getValue(), columnNames).write(iterator)).iterator();
+        return iterator -> Collections.singleton(new RecordWriter(config.getValue(), columnNames).write(iterator)).iterator();
     }
 
     /**
@@ -345,8 +410,8 @@ public class CassandraBulkSourceRelation extends BaseRelation implements Inserta
     {
         try
         {
-            LOGGER.info("Unpersisting broadcast context");
-            broadcastContext.unpersist(false);
+            LOGGER.info("Unpersisting broadcast config");
+            broadcastConfig.unpersist(false);
         }
         catch (Throwable throwable)
         {
@@ -460,18 +525,26 @@ public class CassandraBulkSourceRelation extends BaseRelation implements Inserta
                                             .toRestoreJobSecrets();
             CoordinatedWriteConf.ClusterConf cluster = coordinatedWriteConf.cluster(clusterId);
             String localDc = cluster.resolveLocalDc(cl); // resolve the cluster specific localDc name
-            CreateRestoreJobRequestPayload payload = createJobPayloadBuilder(job, secrets)
+            CreateRestoreJobRequestPayload payload = createJobPayloadBuilder(job, secrets, clusterId)
                                                      .consistencyLevel(toSidecarConsistencyLevel(cl), localDc)
+                                                     // TODO: add test case once we advance the sidecar version that understands the flag,
+                                                     //       or a better testing strategy is figured out
+                                                     .restoreToLocalDatacenterOnly(cluster.writeToLocalDcOnly())
                                                      .build();
             api.createRestoreJob(payload);
         });
     }
 
     private CreateRestoreJobRequestPayload.Builder createJobPayloadBuilder(JobInfo job, RestoreJobSecrets secrets)
+    {
+        return createJobPayloadBuilder(job, secrets, null);
+    }
+
+    private CreateRestoreJobRequestPayload.Builder createJobPayloadBuilder(JobInfo job, RestoreJobSecrets secrets, String clusterId)
     {
         CreateRestoreJobRequestPayload.Builder builder = CreateRestoreJobRequestPayload.builder(secrets, updatedLeaseTime());
         builder.jobAgent(BuildInfo.APPLICATION_NAME)
-               .jobId(job.getRestoreJobId())
+               .jobId(job.getRestoreJobId(clusterId))
                .updateImportOptions(importOptions -> {
                    importOptions.verifySSTables(true) // we disallow the end-user to bypass the non-extended verify anymore
                                 .extendedVerify(false); // always turn off
@@ -487,15 +560,14 @@ public class CassandraBulkSourceRelation extends BaseRelation implements Inserta
     private void setSliceCountForRestoreJob(TransportContext.CloudStorageTransportContext context, long sliceCount)
     {
         UpdateRestoreJobRequestPayload requestPayload = UpdateRestoreJobRequestPayload.builder().withSliceCount(sliceCount).build();
-        UUID jobId = writerContext.job().getRestoreJobId();
         try
         {
-            LOGGER.info("Setting slice count for the restore job. jobId={} sliceCount={}", jobId, sliceCount);
+            LOGGER.info("Setting slice count for the restore job. sliceCount={}", sliceCount);
             context.dataTransferApi().updateRestoreJob(requestPayload);
         }
         catch (Exception e)
         {
-            LOGGER.warn("Failed to set slice count for the restore job. jobId={}", jobId, e);
+            LOGGER.warn("Failed to set slice count for the restore job.", e);
             // Do not rethrow - avoid triggering the catch block at the call-site that marks job as failed.
         }
     }
@@ -503,17 +575,16 @@ public class CassandraBulkSourceRelation extends BaseRelation implements Inserta
     private void markRestoreJobAsSucceeded(TransportContext.CloudStorageTransportContext context)
     {
         UpdateRestoreJobRequestPayload requestPayload = UpdateRestoreJobRequestPayload.builder().withStatus(RestoreJobStatus.SUCCEEDED).build();
-        UUID jobId = writerContext.job().getRestoreJobId();
         try
         {
-            LOGGER.info("Marking the restore job as succeeded. jobId={}", jobId);
+            LOGGER.info("Marking the restore job as succeeded.");
             // Prioritize the call to extension, so onJobSucceeded is always invoked.
             context.transportExtensionImplementation().onJobSucceeded(elapsedTimeMillis());
             context.dataTransferApi().updateRestoreJob(requestPayload);
         }
         catch (Exception e)
         {
-            LOGGER.warn("Failed to mark the restore job as succeeded. jobId={}", jobId, e);
+            LOGGER.warn("Failed to mark the restore job as succeeded.", e);
             // Do not rethrow - avoid triggering the catch block at the call-site that marks job as failed.
         }
     }
@@ -522,8 +593,6 @@ public class CassandraBulkSourceRelation extends BaseRelation implements Inserta
     {
         // Prioritize the call to extension, so onJobFailed is always invoked.
         context.transportExtensionImplementation().onJobFailed(elapsedTimeMillis(), cause);
-        UUID jobId = writerContext.job().getRestoreJobId();
-        LOGGER.info("Aborting job. jobId={}", jobId);
         context.dataTransferApi().abortRestoreJob();
     }
 
