@@ -39,7 +39,7 @@ import org.apache.cassandra.bridge.CassandraBridge;
 import org.apache.cassandra.bridge.CassandraBridgeFactory;
 import org.apache.cassandra.bridge.SSTableDescriptor;
 import org.apache.cassandra.clients.Sidecar;
-import org.apache.cassandra.sidecar.client.SidecarInstance;
+import o.a.c.sidecar.client.shaded.client.SidecarInstance;
 import org.apache.cassandra.spark.bulkwriter.BulkWriteValidator;
 import org.apache.cassandra.spark.bulkwriter.BulkWriterContext;
 import org.apache.cassandra.spark.bulkwriter.JobInfo;
@@ -95,7 +95,7 @@ public class CloudStorageStreamSession extends StreamSession<TransportContext.Cl
 
         JobInfo job = bulkWriterContext.job();
         long maxSizePerBundleInBytes = job.transportInfo().getMaxSizePerBundleInBytes();
-        this.bundleNameGenerator = new BundleNameGenerator(job.getRestoreJobId().toString(), sessionID);
+        this.bundleNameGenerator = new BundleNameGenerator(job.getId(), sessionID);
         this.dataTransferApi = transportContext.dataTransferApi();
         this.bridge = bridge;
         QualifiedTableName qualifiedTableName = job.qualifiedTableName();
