@@ -21,7 +21,9 @@ package org.apache.cassandra.spark;
 
 import java.math.BigInteger;
 import java.util.Arrays;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.UUID;
 
 import com.google.common.collect.ImmutableList;
@@ -34,6 +36,7 @@ import com.esotericsoftware.kryo.Kryo;
 import com.esotericsoftware.kryo.io.Input;
 import com.esotericsoftware.kryo.io.Output;
 import org.apache.cassandra.bridge.CassandraBridge;
+import org.apache.cassandra.bridge.CassandraVersion;
 import org.apache.cassandra.secrets.SslConfig;
 import org.apache.cassandra.spark.bulkwriter.cloudstorage.coordinated.MultiClusterContainer;
 import org.apache.cassandra.spark.bulkwriter.util.SbwKryoRegistrator;
@@ -50,8 +53,7 @@ import org.apache.cassandra.spark.transports.storage.StorageCredentials;
 import org.apache.cassandra.spark.transports.storage.extensions.StorageTransportConfiguration;
 import org.apache.cassandra.spark.utils.RandomUtils;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.assertj.core.api.Assertions.assertThat;
 import static org.quicktheories.QuickTheory.qt;
 import static org.quicktheories.generators.SourceDSL.arbitrary;
 import static org.quicktheories.generators.SourceDSL.booleans;
@@ -59,27 +61,40 @@ import static org.quicktheories.generators.SourceDSL.integers;
 
 public class KryoSerializationTests
 {
-    private static final Kryo KRYO = new Kryo();
+    private static final Map<CassandraVersion, Kryo> KRYO = new HashMap<>();
 
     static
     {
-        new KryoRegister().registerClasses(KRYO);
+        try
+        {
+            for (Map.Entry<CassandraVersion, Class<?>> entry : KryoRegister.KRYO_REGISTRATORS.entrySet())
+            {
+                Kryo kryo = new Kryo();
+                KryoRegister register = (KryoRegister) entry.getValue().getDeclaredConstructor().newInstance();
+                register.registerClasses(kryo);
+                KRYO.put(entry.getKey(), kryo);
+            }
+        }
+        catch (Exception e)
+        {
+            throw new RuntimeException(e);
+        }
     }
 
-    private static Output serialize(Object object)
+    private static Output serialize(CassandraVersion version, Object object)
     {
         try (Output out = new Output(1024, -1))
         {
-            KRYO.writeObject(out, object);
+            KRYO.get(version).writeObject(out, object);
             return out;
         }
     }
 
-    private static <T> T deserialize(Output output, Class<T> type)
+    private static <T> T deserialize(CassandraVersion version, Output output, Class<T> type)
     {
         try (Input in = new Input(output.getBuffer(), 0, output.position()))
         {
-            return KRYO.readObject(in, type);
+            return KRYO.get(version).readObject(in, type);
         }
     }
 
@@ -96,14 +111,14 @@ public class KryoSerializationTests
                                               RandomUtils.randomAlphanumeric(5, 20),
                                               cqlType,
                                               position);
-                Output out = serialize(field);
-                CqlField deserialized = deserialize(out, CqlField.class);
-                assertEquals(field, deserialized);
-                assertEquals(field.name(), deserialized.name());
-                assertEquals(field.type(), deserialized.type());
-                assertEquals(field.position(), deserialized.position());
-                assertEquals(field.isPartitionKey(), deserialized.isPartitionKey());
-                assertEquals(field.isClusteringColumn(), deserialized.isClusteringColumn());
+                Output out = serialize(bridge.getVersion(), field);
+                CqlField deserialized = deserialize(bridge.getVersion(), out, CqlField.class);
+                assertThat(deserialized).isEqualTo(field);
+                assertThat(deserialized.name()).isEqualTo(field.name());
+                assertThat(deserialized.type()).isEqualTo(field.type());
+                assertThat(deserialized.position()).isEqualTo(field.position());
+                assertThat(deserialized.isPartitionKey()).isEqualTo(field.isPartitionKey());
+                assertThat(deserialized.isClusteringColumn()).isEqualTo(field.isClusteringColumn());
             });
     }
 
@@ -121,14 +136,14 @@ public class KryoSerializationTests
                                               RandomUtils.randomAlphanumeric(5, 20),
                                               setType,
                                               position);
-                Output out = serialize(field);
-                CqlField deserialized = deserialize(out, CqlField.class);
-                assertEquals(field, deserialized);
-                assertEquals(field.name(), deserialized.name());
-                assertEquals(field.type(), deserialized.type());
-                assertEquals(field.position(), deserialized.position());
-                assertEquals(field.isPartitionKey(), deserialized.isPartitionKey());
-                assertEquals(field.isClusteringColumn(), deserialized.isClusteringColumn());
+                Output out = serialize(bridge.getVersion(), field);
+                CqlField deserialized = deserialize(bridge.getVersion(), out, CqlField.class);
+                assertThat(deserialized).isEqualTo(field);
+                assertThat(deserialized.name()).isEqualTo(field.name());
+                assertThat(deserialized.type()).isEqualTo(field.type());
+                assertThat(deserialized.position()).isEqualTo(field.position());
+                assertThat(deserialized.isPartitionKey()).isEqualTo(field.isPartitionKey());
+                assertThat(deserialized.isClusteringColumn()).isEqualTo(field.isClusteringColumn());
             });
     }
 
@@ -146,14 +161,14 @@ public class KryoSerializationTests
                                               RandomUtils.randomAlphanumeric(5, 20),
                                               listType,
                                               position);
-                Output out = serialize(field);
-                CqlField deserialized = deserialize(out, CqlField.class);
-                assertEquals(field, deserialized);
-                assertEquals(field.name(), deserialized.name());
-                assertEquals(field.type(), deserialized.type());
-                assertEquals(field.position(), deserialized.position());
-                assertEquals(field.isPartitionKey(), deserialized.isPartitionKey());
-                assertEquals(field.isClusteringColumn(), deserialized.isClusteringColumn());
+                Output out = serialize(bridge.getVersion(), field);
+                CqlField deserialized = deserialize(bridge.getVersion(), out, CqlField.class);
+                assertThat(deserialized).isEqualTo(field);
+                assertThat(deserialized.name()).isEqualTo(field.name());
+                assertThat(deserialized.type()).isEqualTo(field.type());
+                assertThat(deserialized.position()).isEqualTo(field.position());
+                assertThat(deserialized.isPartitionKey()).isEqualTo(field.isPartitionKey());
+                assertThat(deserialized.isClusteringColumn()).isEqualTo(field.isClusteringColumn());
             });
     }
 
@@ -171,14 +186,14 @@ public class KryoSerializationTests
                                               RandomUtils.randomAlphanumeric(5, 20),
                                               mapType,
                                               2);
-                Output out = serialize(field);
-                CqlField deserialized = deserialize(out, CqlField.class);
-                assertEquals(field, deserialized);
-                assertEquals(field.name(), deserialized.name());
-                assertEquals(field.type(), deserialized.type());
-                assertEquals(field.position(), deserialized.position());
-                assertEquals(field.isPartitionKey(), deserialized.isPartitionKey());
-                assertEquals(field.isClusteringColumn(), deserialized.isClusteringColumn());
+                Output out = serialize(bridge.getVersion(), field);
+                CqlField deserialized = deserialize(bridge.getVersion(), out, CqlField.class);
+                assertThat(deserialized).isEqualTo(field);
+                assertThat(deserialized.name()).isEqualTo(field.name());
+                assertThat(deserialized.type()).isEqualTo(field.type());
+                assertThat(deserialized.position()).isEqualTo(field.position());
+                assertThat(deserialized.isPartitionKey()).isEqualTo(field.isPartitionKey());
+                assertThat(deserialized.isClusteringColumn()).isEqualTo(field.isClusteringColumn());
             });
     }
 
@@ -194,14 +209,14 @@ public class KryoSerializationTests
                                             .withField("b", type2)
                                             .build();
                 CqlField field = new CqlField(false, false, false, RandomUtils.randomAlphanumeric(5, 20), udt, 2);
-                Output out = serialize(field);
-                CqlField deserialized = deserialize(out, CqlField.class);
-                assertEquals(field, deserialized);
-                assertEquals(field.name(), deserialized.name());
-                assertEquals(udt, deserialized.type());
-                assertEquals(field.position(), deserialized.position());
-                assertEquals(field.isPartitionKey(), deserialized.isPartitionKey());
-                assertEquals(field.isClusteringColumn(), deserialized.isClusteringColumn());
+                Output out = serialize(bridge.getVersion(), field);
+                CqlField deserialized = deserialize(bridge.getVersion(), out, CqlField.class);
+                assertThat(deserialized).isEqualTo(field);
+                assertThat(deserialized.name()).isEqualTo(field.name());
+                assertThat(deserialized.type()).isEqualTo(udt);
+                assertThat(deserialized.position()).isEqualTo(field.position());
+                assertThat(deserialized.isPartitionKey()).isEqualTo(field.isPartitionKey());
+                assertThat(deserialized.isClusteringColumn()).isEqualTo(field.isClusteringColumn());
             });
     }
 
@@ -219,14 +234,14 @@ public class KryoSerializationTests
                                                        bridge.bigint(),
                                                        bridge.map(type2, bridge.timeuuid()));
                 CqlField field = new CqlField(false, false, false, RandomUtils.randomAlphanumeric(5, 20), tuple, 2);
-                Output out = serialize(field);
-                CqlField deserialized = deserialize(out, CqlField.class);
-                assertEquals(field, deserialized);
-                assertEquals(field.name(), deserialized.name());
-                assertEquals(tuple, deserialized.type());
-                assertEquals(field.position(), deserialized.position());
-                assertEquals(field.isPartitionKey(), deserialized.isPartitionKey());
-                assertEquals(field.isClusteringColumn(), deserialized.isClusteringColumn());
+                Output out = serialize(bridge.getVersion(), field);
+                CqlField deserialized = deserialize(bridge.getVersion(), out, CqlField.class);
+                assertThat(deserialized).isEqualTo(field);
+                assertThat(deserialized.name()).isEqualTo(field.name());
+                assertThat(deserialized.type()).isEqualTo(tuple);
+                assertThat(deserialized.position()).isEqualTo(field.position());
+                assertThat(deserialized.isPartitionKey()).isEqualTo(field.isPartitionKey());
+                assertThat(deserialized.isClusteringColumn()).isEqualTo(field.isClusteringColumn());
             });
     }
 
@@ -248,35 +263,35 @@ public class KryoSerializationTests
                                       replicationFactor,
                                       fields);
 
-        Output out = serialize(table);
-        CqlTable deserialized = deserialize(out, CqlTable.class);
-        assertNotNull(deserialized);
-        assertEquals(table, deserialized);
+        Output out = serialize(bridge.getVersion(), table);
+        CqlTable deserialized = deserialize(bridge.getVersion(), out, CqlTable.class);
+        assertThat(deserialized).isNotNull();
+        assertThat(deserialized).isEqualTo(table);
     }
 
     @ParameterizedTest
     @MethodSource("org.apache.cassandra.bridge.VersionRunner#bridges")
-    public void testCassandraInstance()
+    public void testCassandraInstance(CassandraBridge bridge)
     {
         CassandraInstance instance = new CassandraInstance("-9223372036854775807", "local1-i1", "DC1");
-        Output out = serialize(instance);
-        CassandraInstance deserialized = deserialize(out, CassandraInstance.class);
-        assertNotNull(deserialized);
-        assertEquals(instance, deserialized);
+        Output out = serialize(bridge.getVersion(), instance);
+        CassandraInstance deserialized = deserialize(bridge.getVersion(), out, CassandraInstance.class);
+        assertThat(deserialized).isNotNull();
+        assertThat(deserialized).isEqualTo(instance);
     }
 
     @ParameterizedTest
     @MethodSource("org.apache.cassandra.bridge.VersionRunner#bridges")
-    public void testCassandraRing()
+    public void testCassandraRing(CassandraBridge bridge)
     {
         qt().forAll(TestUtils.partitioners())
             .checkAssert(partitioner -> {
                 CassandraRing ring = TestUtils.createRing(partitioner, ImmutableMap.of("DC1", 3, "DC2", 3));
-                Output out = serialize(ring);
-                CassandraRing deserialized = deserialize(out, CassandraRing.class);
-                assertNotNull(deserialized);
-                assertEquals(ring, deserialized);
-                assertEquals(partitioner, deserialized.partitioner());
+                Output out = serialize(bridge.getVersion(), ring);
+                CassandraRing deserialized = deserialize(bridge.getVersion(), out, CassandraRing.class);
+                assertThat(deserialized).isNotNull();
+                assertThat(deserialized).isEqualTo(ring);
+                assertThat(deserialized.partitioner()).isEqualTo(partitioner);
             });
     }
 
@@ -294,15 +309,16 @@ public class KryoSerializationTests
                                                            path1,
                                                            path2,
                                                            path3);
-        Output out = serialize(localDataLayer);
-        LocalDataLayer deserialized = deserialize(out, LocalDataLayer.class);
-        assertNotNull(deserialized);
-        assertEquals(localDataLayer.version(), deserialized.version());
-        assertEquals(localDataLayer, deserialized);
+        Output out = serialize(bridge.getVersion(), localDataLayer);
+        LocalDataLayer deserialized = deserialize(bridge.getVersion(), out, LocalDataLayer.class);
+        assertThat(deserialized).isNotNull();
+        assertThat(deserialized.version()).isEqualTo(localDataLayer.version());
+        assertThat(deserialized).isEqualTo(localDataLayer);
     }
 
-    @Test
-    public void testTokenPartitioner()
+    @ParameterizedTest
+    @MethodSource("org.apache.cassandra.bridge.VersionRunner#bridges")
+    public void testTokenPartitioner(CassandraBridge bridge)
     {
         qt().forAll(TestUtils.partitioners(),
                     arbitrary().pick(Arrays.asList(3, 16, 128)),
@@ -311,16 +327,16 @@ public class KryoSerializationTests
             .checkAssert((partitioner, numInstances, defaultParallelism, numCores) -> {
                 CassandraRing ring = TestUtils.createRing(partitioner, numInstances);
                 TokenPartitioner tokenPartitioner = new TokenPartitioner(ring, defaultParallelism, numCores);
-                Output out = serialize(tokenPartitioner);
-                TokenPartitioner deserialized = deserialize(out, TokenPartitioner.class);
-                assertNotNull(deserialized);
-                assertEquals(tokenPartitioner.numPartitions(), deserialized.numPartitions());
-                assertEquals(tokenPartitioner.subRanges().size(), deserialized.subRanges().size());
+                Output out = serialize(bridge.getVersion(), tokenPartitioner);
+                TokenPartitioner deserialized = deserialize(bridge.getVersion(), out, TokenPartitioner.class);
+                assertThat(deserialized).isNotNull();
+                assertThat(deserialized.numPartitions()).isEqualTo(tokenPartitioner.numPartitions());
+                assertThat(deserialized.subRanges()).hasSameSizeAs(tokenPartitioner.subRanges());
                 for (int index = 0; index < tokenPartitioner.subRanges().size(); index++)
                 {
-                    assertEquals(tokenPartitioner.subRanges().get(index), deserialized.subRanges().get(index));
+                    assertThat(deserialized.subRanges().get(index)).isEqualTo(tokenPartitioner.subRanges().get(index));
                 }
-                assertEquals(tokenPartitioner.ring(), deserialized.ring());
+                assertThat(deserialized.ring()).isEqualTo(tokenPartitioner.ring());
             });
     }
 
@@ -338,15 +354,16 @@ public class KryoSerializationTests
         out.close();
         Input in = new Input(out.getBuffer(), 0, out.position());
         CqlField.CqlUdt deserialized = (CqlField.CqlUdt) CqlField.CqlType.read(in, bridge.cassandraTypes());
-        assertEquals(udt, deserialized);
+        assertThat(deserialized).isEqualTo(udt);
         for (int index = 0; index < deserialized.fields().size(); index++)
         {
-            assertEquals(udt.field(index), deserialized.field(index));
+            assertThat(deserialized.field(index)).isEqualTo(udt.field(index));
         }
     }
 
-    @Test
-    public void testSslConfig()
+    @ParameterizedTest
+    @MethodSource("org.apache.cassandra.bridge.VersionRunner#bridges")
+    public void testSslConfig(CassandraBridge bridge)
     {
         SslConfig config = new SslConfig.Builder<>()
                            .keyStorePath("keyStorePath")
@@ -358,17 +375,17 @@ public class KryoSerializationTests
                            .trustStorePassword("trustStorePassword")
                            .trustStoreType("trustStoreType")
                            .build();
-        Output out = serialize(config);
-        SslConfig deserialized = deserialize(out, SslConfig.class);
+        Output out = serialize(bridge.getVersion(), config);
+        SslConfig deserialized = deserialize(bridge.getVersion(), out, SslConfig.class);
 
-        assertEquals(config.keyStorePath(), deserialized.keyStorePath());
-        assertEquals(config.base64EncodedKeyStore(), deserialized.base64EncodedKeyStore());
-        assertEquals(config.keyStorePassword(), deserialized.keyStorePassword());
-        assertEquals(config.keyStoreType(), deserialized.keyStoreType());
-        assertEquals(config.trustStorePath(), deserialized.trustStorePath());
-        assertEquals(config.base64EncodedTrustStore(), deserialized.base64EncodedTrustStore());
-        assertEquals(config.trustStorePassword(), deserialized.trustStorePassword());
-        assertEquals(config.trustStoreType(), deserialized.trustStoreType());
+        assertThat(deserialized.keyStorePath()).isEqualTo(config.keyStorePath());
+        assertThat(deserialized.base64EncodedKeyStore()).isEqualTo(config.base64EncodedKeyStore());
+        assertThat(deserialized.keyStorePassword()).isEqualTo(config.keyStorePassword());
+        assertThat(deserialized.keyStoreType()).isEqualTo(config.keyStoreType());
+        assertThat(deserialized.trustStorePath()).isEqualTo(config.trustStorePath());
+        assertThat(deserialized.base64EncodedTrustStore()).isEqualTo(config.base64EncodedTrustStore());
+        assertThat(deserialized.trustStorePassword()).isEqualTo(config.trustStorePassword());
+        assertThat(deserialized.trustStoreType()).isEqualTo(config.trustStoreType());
     }
 
     @Test
@@ -428,16 +445,17 @@ public class KryoSerializationTests
     private static <T> void testSerDeser(Object origin, Class<T> type)
     {
         T deserialized;
-        try (Output out = serialize(origin))
+        try (Output out = serialize(CassandraVersion.FOURZERO, origin))
         {
-            deserialized = deserialize(out, type);
+            deserialized = deserialize(CassandraVersion.FOURZERO, out, type);
         }
-        assertEquals(origin, deserialized);
+        assertThat(deserialized).isEqualTo(origin);
     }
 
     static
     {
-        new KryoRegister().registerClasses(KRYO);
-        new SbwKryoRegistrator().registerClasses(KRYO);
+        Kryo kryo = KRYO.get(CassandraVersion.FOURZERO);
+        new KryoRegister(CassandraVersion.FOURZERO).registerClasses(kryo);
+        new SbwKryoRegistrator().registerClasses(kryo);
     }
 }
