@@ -52,8 +52,7 @@ import org.jetbrains.annotations.Nullable;
 import org.quicktheories.core.Gen;
 
 import static org.apache.cassandra.bridge.CassandraBridgeFactory.getSparkSql;
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.assertj.core.api.Assertions.assertThat;
 import static org.quicktheories.QuickTheory.qt;
 import static org.quicktheories.generators.SourceDSL.arbitrary;
 
@@ -147,9 +146,8 @@ public final class Tester
 
     public static final class Builder
     {
-        // TODO: Make use of TestUtils.testableVersions() instead
         @NotNull
-        private List<CassandraVersion> versions = ImmutableList.of(CassandraVersion.FOURZERO);
+        private List<CassandraVersion> versions = TestUtils.testableVersions();
         @Nullable
         private TestSchema.Builder schemaBuilder;
         @Nullable
@@ -192,39 +190,39 @@ public final class Tester
         }
 
         // Runs a test for every Cassandra version given
-        Builder withVersions(@NotNull Collection<CassandraVersion> versions)
+        public Builder withVersions(@NotNull Collection<CassandraVersion> versions)
         {
             this.versions = ImmutableList.copyOf(versions);
             return this;
         }
 
         // Runs a test for every number of SSTables given
-        Builder withNumRandomSSTables(Integer... numSSTables)
+        public Builder withNumRandomSSTables(Integer... numSSTables)
         {
             this.numSSTables = ImmutableList.copyOf(numSSTables);
             return this;
         }
 
-        Builder withSumField(String... fields)
+        public Builder withSumField(String... fields)
         {
             sumFields = ImmutableSet.copyOf(fields);
             return this;
         }
 
-        Builder withNumRandomRows(int numRow)
+        public Builder withNumRandomRows(int numRow)
         {
             numRandomRows = numRow;
             return this;
         }
 
-        Builder dontWriteRandomData()
+        public Builder dontWriteRandomData()
         {
             numSSTables = ImmutableList.of(0);
             numRandomRows = 0;
             return this;
         }
 
-        Builder withWriteListener(@Nullable Consumer<TestSchema.TestRow> writeListener)
+        public Builder withWriteListener(@Nullable Consumer<TestSchema.TestRow> writeListener)
         {
             if (writeListener != null)
             {
@@ -233,7 +231,7 @@ public final class Tester
             return this;
         }
 
-        Builder withReadListener(@Nullable Consumer<TestSchema.TestRow> readListener)
+        public Builder withReadListener(@Nullable Consumer<TestSchema.TestRow> readListener)
         {
             if (readListener != null)
             {
@@ -242,7 +240,7 @@ public final class Tester
             return this;
         }
 
-        Builder withSSTableWriter(@Nullable Consumer<CassandraBridge.Writer> consumer)
+        public Builder withSSTableWriter(@Nullable Consumer<CassandraBridge.Writer> consumer)
         {
             if (consumer != null)
             {
@@ -251,7 +249,7 @@ public final class Tester
             return this;
         }
 
-        Builder withTombstoneWriter(@Nullable Consumer<CassandraBridge.Writer> consumer)
+        public Builder withTombstoneWriter(@Nullable Consumer<CassandraBridge.Writer> consumer)
         {
             if (consumer != null)
             {
@@ -260,7 +258,7 @@ public final class Tester
             return this;
         }
 
-        Builder withCheck(@Nullable Consumer<Dataset<Row>> check)
+        public Builder withCheck(@Nullable Consumer<Dataset<Row>> check)
         {
             if (check != null)
             {
@@ -269,49 +267,49 @@ public final class Tester
             return this;
         }
 
-        Builder withExpectedRowCountPerSSTable(int expectedRowCount)
+        public Builder withExpectedRowCountPerSSTable(int expectedRowCount)
         {
             this.expectedRowCount = expectedRowCount;
             return this;
         }
 
-        Builder withReset(Runnable reset)
+        public Builder withReset(Runnable reset)
         {
             this.reset = reset;
             return this;
         }
 
-        Builder withFilter(@NotNull String filterExpression)
+        public Builder withFilter(@NotNull String filterExpression)
         {
             this.filterExpression = filterExpression;
             return this;
         }
 
-        Builder withColumns(@NotNull String... columns)
+        public Builder withColumns(@NotNull String... columns)
         {
             this.columns = columns;
             return this;
         }
 
-        Builder dontCheckNumSSTables()
+        public Builder dontCheckNumSSTables()
         {
             shouldCheckNumSSTables = false;
             return this;
         }
 
-        Builder withLastModifiedTimestampColumn()
+        public Builder withLastModifiedTimestampColumn()
         {
             addLastModifiedTimestamp = true;
             return this;
         }
 
-        Builder withDelayBetweenSSTablesInSecs(int delay)
+        public Builder withDelayBetweenSSTablesInSecs(int delay)
         {
             delayBetweenSSTablesInSecs = delay;
             return this;
         }
 
-        Builder withStatsClass(String statsClass)
+        public Builder withStatsClass(String statsClass)
         {
             this.statsClass = statsClass;
             return this;
@@ -334,6 +332,12 @@ public final class Tester
             Preconditions.checkArgument(schemaBuilder != null || schemaBuilderFunc != null);
             new Tester(this).run();
         }
+
+        public void run(CassandraVersion... versions)
+        {
+            Preconditions.checkArgument(schemaBuilder != null || schemaBuilderFunc != null);
+            new Tester(this).run(versions);
+        }
     }
 
     private void run()
@@ -342,6 +346,12 @@ public final class Tester
             .checkAssert(this::run);
     }
 
+    private void run(CassandraVersion... versions)
+    {
+        qt().forAll(arbitrary().pick(Arrays.asList(versions)), numSSTables())
+            .checkAssert(this::run);
+    }
+
     private Gen<CassandraVersion> versions()
     {
         return arbitrary().pick(versions);
@@ -423,8 +433,9 @@ public final class Tester
 
             if (shouldCheckNumSSTables)
             {
-                assertEquals(sstableCount, TestUtils.countSSTables(directory),
-                             "Number of SSTables written does not match expected");
+                assertThat(TestUtils.countSSTables(directory))
+                .as("Number of SSTables written does not match expected")
+                .isEqualTo(sstableCount);
             }
 
             Dataset<Row> dataset = TestUtils.openLocalDataset(bridge,
@@ -445,8 +456,9 @@ public final class Tester
                 if (requiredColumns != null)
                 {
                     Set<String> actualColumns = new HashSet<>(Arrays.asList(row.schema().fieldNames()));
-                    assertEquals(actualColumns, requiredColumns,
-                                 "Actual Columns and Required Columns should be the same");
+                    assertThat(actualColumns)
+                    .as("Actual Columns and Required Columns should be the same")
+                    .isEqualTo(requiredColumns);
                 }
 
                 TestSchema.TestRow actualRow = schema.toTestRow(row, requiredColumns, getSparkSql(version));
@@ -454,9 +466,12 @@ public final class Tester
                 {
                     // If we wrote random data, verify values exist
                     String key = actualRow.getPrimaryHexKey();
-                    assertTrue(rows.containsKey(key), "Unexpected row read in Spark");
-                    assertEquals(rows.get(key).withColumns(requiredColumns), actualRow,
-                                 "Row read in Spark does not match expected");
+                    assertThat(rows.containsKey(key))
+                    .as("Unexpected row read in Spark")
+                    .isTrue();
+                    assertThat(rows.get(key).withColumns(requiredColumns))
+                    .as("Row read in Spark does not match expected")
+                    .isEqualTo(actualRow);
                 }
 
                 for (Consumer<TestSchema.TestRow> readListener : readListeners)
@@ -467,15 +482,17 @@ public final class Tester
             }
             if (expectedRowCount >= 0)
             {
-                assertEquals(expectedRowCount * sstableCount, rowCount, "Number of rows read does not match expected");
+                assertThat(rowCount)
+                .as("Number of rows read does not match expected")
+                .isEqualTo(expectedRowCount * sstableCount);
             }
 
             // Verify numerical fields sum to expected value
             for (String sumField : sumFields)
             {
-                assertEquals(sum.get(sumField).getValue().longValue(),
-                             dataset.groupBy().sum(sumField).first().getLong(0),
-                             "Field '" + sumField + "' does not sum to expected amount");
+                assertThat(dataset.groupBy().sum(sumField).first().getLong(0))
+                .as("Field '%s' does not sum to expected amount", sumField)
+                .isEqualTo(sum.get(sumField).getValue().longValue());
             }
 
             // Run SparkSQL checks
