@@ -27,6 +27,7 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.NoSuchElementException;
 import java.util.Set;
 import java.util.UUID;
 import java.util.concurrent.ConcurrentHashMap;
@@ -42,7 +43,6 @@ import org.apache.commons.lang3.tuple.Pair;
 
 import org.apache.cassandra.bridge.CassandraBridge;
 import org.apache.cassandra.bridge.CassandraBridgeFactory;
-import org.apache.cassandra.bridge.CassandraVersion;
 import org.apache.cassandra.spark.bulkwriter.cloudstorage.coordinated.CoordinatedWriteConf;
 import org.apache.cassandra.spark.bulkwriter.token.ConsistencyLevel;
 import org.apache.cassandra.spark.bulkwriter.token.ReplicaAwareFailureHandler;
@@ -82,7 +82,6 @@ public class MockBulkWriterContext implements BulkWriterContext, ClusterInfo, Jo
     new CqlField.CqlType[]{mockCqlType(INT), mockCqlType(DATE), mockCqlType(VARCHAR), mockCqlType(INT)});
     private ConsistencyLevel.CL consistencyLevel;
     private int sstableDataSizeInMB = 128;
-    private CassandraBridge bridge = CassandraBridgeFactory.get(CassandraVersion.FOURZERO);
     private TimeSkewTooLargeException timeSkewTooLargeException;
 
     @Override
@@ -95,7 +94,7 @@ public class MockBulkWriterContext implements BulkWriterContext, ClusterInfo, Jo
     {
     }
 
-    public static final String DEFAULT_CASSANDRA_VERSION = "cassandra-4.0.2";
+    public static final String DEFAULT_CASSANDRA_VERSION = "cassandra-5.0.5";
 
     private final UUID jobId;
     private boolean skipClean = false;
@@ -109,6 +108,7 @@ public class MockBulkWriterContext implements BulkWriterContext, ClusterInfo, Jo
     private boolean cleanShouldThrow = false;
     private final TokenPartitioner tokenPartitioner;
     private final String cassandraVersion;
+    private final CassandraBridge bridge;
     private CommitResultSupplier crSupplier = (uuids, dc) -> new DirectDataTransferApi.RemoteCommitResult(true, Collections.emptyList(), uuids, null);
     private Predicate<CassandraInstance> uploadRequestConsumer = instance -> true;
     private ReplicationFactor replicationFactor;
@@ -144,11 +144,12 @@ public class MockBulkWriterContext implements BulkWriterContext, ClusterInfo, Jo
         this.cassandraVersion = cassandraVersion;
         this.consistencyLevel = consistencyLevel;
         this.validPair = validPair;
+        this.bridge = CassandraBridgeFactory.get(cassandraVersion);
         StructType validDataFrameSchema = this.validPair.getKey();
         ImmutableMap<String, CqlField.CqlType> validCqlColumns = this.validPair.getValue();
         ColumnType<?>[] partitionKeyColumnTypes = {ColumnTypes.INT, ColumnTypes.INT};
         TTLOption ttlOption = TTLOption.forever();
-        TableSchemaTestCommon.MockTableSchemaBuilder builder = new TableSchemaTestCommon.MockTableSchemaBuilder(CassandraBridgeFactory.get(cassandraVersion))
+        TableSchemaTestCommon.MockTableSchemaBuilder builder = new TableSchemaTestCommon.MockTableSchemaBuilder(bridge)
                                                                .withCqlColumns(validCqlColumns)
                                                                .withPartitionKeyColumns(partitionKeyColumns)
                                                                .withPrimaryKeyColumnNames(primaryKeyColumnNames)
@@ -332,6 +333,12 @@ public class MockBulkWriterContext implements BulkWriterContext, ClusterInfo, Jo
         return jobId;
     }
 
+    @Override
+    public UUID getRestoreJobId(@Nullable String clusterId) throws NoSuchElementException
+    {
+        return jobId;
+    }
+
     @Override
     public String getConfiguredJobId()
     {
