@@ -36,17 +36,17 @@ import o.a.c.sidecar.client.shaded.common.response.NodeSettings;
 import o.a.c.sidecar.client.shaded.io.vertx.core.Vertx;
 import o.a.c.sidecar.client.shaded.io.vertx.core.VertxOptions;
 import org.apache.cassandra.secrets.SecretsProvider;
-import org.apache.cassandra.sidecar.client.HttpClientConfig;
-import org.apache.cassandra.sidecar.client.SidecarClient;
-import org.apache.cassandra.sidecar.client.SidecarClientConfig;
-import org.apache.cassandra.sidecar.client.SidecarClientConfigImpl;
-import org.apache.cassandra.sidecar.client.SidecarInstance;
-import org.apache.cassandra.sidecar.client.SidecarInstanceImpl;
-import org.apache.cassandra.sidecar.client.SidecarInstancesProvider;
-import org.apache.cassandra.sidecar.client.VertxHttpClient;
-import org.apache.cassandra.sidecar.client.VertxRequestExecutor;
-import org.apache.cassandra.sidecar.client.retry.ExponentialBackoffRetryPolicy;
-import org.apache.cassandra.sidecar.client.retry.RetryPolicy;
+import o.a.c.sidecar.client.shaded.client.HttpClientConfig;
+import o.a.c.sidecar.client.shaded.client.SidecarClient;
+import o.a.c.sidecar.client.shaded.client.SidecarClientConfig;
+import o.a.c.sidecar.client.shaded.client.SidecarClientConfigImpl;
+import o.a.c.sidecar.client.shaded.client.SidecarInstance;
+import o.a.c.sidecar.client.shaded.client.SidecarInstanceImpl;
+import o.a.c.sidecar.client.shaded.client.SidecarInstancesProvider;
+import o.a.c.sidecar.client.shaded.client.VertxHttpClient;
+import o.a.c.sidecar.client.shaded.client.VertxRequestExecutor;
+import o.a.c.sidecar.client.shaded.client.retry.ExponentialBackoffRetryPolicy;
+import o.a.c.sidecar.client.shaded.client.retry.RetryPolicy;
 import org.apache.cassandra.spark.common.model.CassandraInstance;
 import org.apache.cassandra.spark.data.FileType;
 import org.apache.cassandra.spark.utils.BuildInfo;
