@@ -263,8 +263,11 @@ public class SSTableReader implements SparkSSTableReader, Scannable
 
         if (keys == null)
         {
-            LOGGER.warn("Could not load first and last key from Summary.db file, so attempting Index.db fileName={}",
-                        ssTable.getDataFileName());
+            if (ssTable.isBigFormat())
+            {
+                LOGGER.warn("Could not load first and last key from Summary.db file, so attempting Index.db fileName={}",
+                            ssTable.getDataFileName());
+            }
             now = System.nanoTime();
             keys = SSTableCache.INSTANCE.keysFromIndex(metadata, ssTable);
             stats.readIndexDb(ssTable, System.nanoTime() - now);
@@ -603,7 +606,9 @@ public class SSTableReader implements SparkSSTableReader, Scannable
         SSTableStreamReader() throws IOException
         {
             lastToken = sparkRangeFilter != null ? sparkRangeFilter.tokenRange().upperEndpoint() : null;
-            @Nullable CompressionMetadata compressionMetadata = SSTableCache.INSTANCE.compressionMetadata(ssTable, version.hasMaxCompressedLength());
+            @Nullable CompressionMetadata compressionMetadata = SSTableCache.INSTANCE.compressionMetadata(ssTable,
+                                                                                                          version.hasMaxCompressedLength(),
+                                                                                                          metadata.params.crcCheckChance);
             DataInputStream dataInputStream = new DataInputStream(ssTable.openDataStream());
 
             if (compressionMetadata != null)
