@@ -60,10 +60,7 @@ import org.apache.cassandra.spark.utils.TemporaryDirectory;
 import org.apache.cassandra.spark.utils.test.TestSSTable;
 import org.apache.cassandra.spark.utils.test.TestSchema;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.assertj.core.api.Assertions.assertThat;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 import static org.quicktheories.QuickTheory.qt;
@@ -94,7 +91,7 @@ public class ReaderUtilsTests
                             }
                         }
                     });
-                    assertEquals(1, TestSSTable.countIn(directory.path()));
+                    assertThat(TestSSTable.countIn(directory.path())).isEqualTo(1);
 
                     String dataFile = TestSSTable.firstIn(directory.path()).getDataFileName();
                     Descriptor descriptor = Descriptor.fromFilename(
@@ -107,33 +104,33 @@ public class ReaderUtilsTests
                     {
                         componentMap = ReaderUtils.deserializeStatsMetadata(in, EnumSet.allOf(MetadataType.class), descriptor);
                     }
-                    assertNotNull(componentMap);
-                    assertFalse(componentMap.isEmpty());
+                    assertThat(componentMap).isNotNull();
+                    assertThat(componentMap.isEmpty()).isFalse();
 
                     ValidationMetadata validationMetadata = (ValidationMetadata) componentMap.get(MetadataType.VALIDATION);
-                    assertEquals("org.apache.cassandra.dht." + partitioner.name(), validationMetadata.partitioner);
+                    assertThat(validationMetadata.partitioner).isEqualTo("org.apache.cassandra.dht." + partitioner.name());
 
                     CompactionMetadata compactionMetadata = (CompactionMetadata) componentMap.get(MetadataType.COMPACTION);
-                    assertNotNull(compactionMetadata);
+                    assertThat(compactionMetadata).isNotNull();
 
                     StatsMetadata statsMetadata = (StatsMetadata) componentMap.get(MetadataType.STATS);
-                    assertEquals(ROWS * COLUMNS, statsMetadata.totalRows);
-                    assertEquals(0L, statsMetadata.repairedAt);
+                    assertThat(statsMetadata.totalRows).isEqualTo(ROWS * COLUMNS);
+                    assertThat(statsMetadata.repairedAt).isEqualTo(0L);
                     // Want to avoid test flakiness but timestamps should be in same ballpark
                     long tolerance = TimeUnit.MICROSECONDS.convert(10, TimeUnit.SECONDS);
-                    assertTrue(Math.abs(statsMetadata.maxTimestamp - nowMicros) < tolerance);
-                    assertTrue(Math.abs(statsMetadata.minTimestamp - nowMicros) < tolerance);
+                    assertThat(Math.abs(statsMetadata.maxTimestamp - nowMicros) < tolerance).isTrue();
+                    assertThat(Math.abs(statsMetadata.minTimestamp - nowMicros) < tolerance).isTrue();
 
                     SerializationHeader.Component header = (SerializationHeader.Component) componentMap.get(MetadataType.HEADER);
-                    assertNotNull(header);
-                    assertEquals("org.apache.cassandra.db.marshal.Int32Type", header.getKeyType().toString());
+                    assertThat(header).isNotNull();
+                    assertThat(header.getKeyType().toString()).isEqualTo("org.apache.cassandra.db.marshal.Int32Type");
                     List<AbstractType<?>> clusteringTypes = header.getClusteringTypes();
-                    assertEquals(1, clusteringTypes.size());
-                    assertEquals("org.apache.cassandra.db.marshal.Int32Type", clusteringTypes.get(0).toString());
-                    assertTrue(header.getStaticColumns().isEmpty());
+                    assertThat(clusteringTypes.size()).isEqualTo(1);
+                    assertThat(clusteringTypes.get(0).toString()).isEqualTo("org.apache.cassandra.db.marshal.Int32Type");
+                    assertThat(header.getStaticColumns().isEmpty()).isTrue();
                     List<AbstractType<?>> regulars = new ArrayList<>(header.getRegularColumns().values());
-                    assertEquals(1, regulars.size());
-                    assertEquals("org.apache.cassandra.db.marshal.Int32Type", regulars.get(0).toString());
+                    assertThat(regulars.size()).isEqualTo(1);
+                    assertThat(regulars.get(0).toString()).isEqualTo("org.apache.cassandra.db.marshal.Int32Type");
                 }
                 catch (IOException exception)
                 {
@@ -160,7 +157,7 @@ public class ReaderUtilsTests
                             }
                         }
                     });
-                    assertEquals(1, TestSSTable.countIn(directory.path()));
+                    assertThat(TestSSTable.countIn(directory.path())).isEqualTo(1);
 
                     // Read Summary.db file for first and last partition keys from Summary.db
                     Path summaryFile = TestSSTable.firstIn(directory.path(), FileType.SUMMARY);
@@ -169,9 +166,9 @@ public class ReaderUtilsTests
                     {
                         summaryKeys = SummaryDbUtils.readSummary(in, Murmur3Partitioner.instance, 128, 2048);
                     }
-                    assertNotNull(summaryKeys);
-                    assertNotNull(summaryKeys.first());
-                    assertNotNull(summaryKeys.last());
+                    assertThat(summaryKeys).isNotNull();
+                    assertThat(summaryKeys.first()).isNotNull();
+                    assertThat(summaryKeys.last()).isNotNull();
 
                     // Read Primary Index.db file for first and last partition keys from Summary.db
                     Path indexFile = TestSSTable.firstIn(directory.path(), FileType.INDEX);
@@ -182,9 +179,9 @@ public class ReaderUtilsTests
                         indexKeys = Pair.of(Murmur3Partitioner.instance.decorateKey(keys.left),
                                             Murmur3Partitioner.instance.decorateKey(keys.right));
                     }
-                    assertNotNull(indexKeys);
-                    assertEquals(indexKeys.left, summaryKeys.first());
-                    assertEquals(indexKeys.right, summaryKeys.last());
+                    assertThat(indexKeys).isNotNull();
+                    assertThat(summaryKeys.first()).isEqualTo(indexKeys.left);
+                    assertThat(summaryKeys.last()).isEqualTo(indexKeys.right);
                 }
                 catch (IOException exception)
                 {
@@ -211,7 +208,7 @@ public class ReaderUtilsTests
                             }
                         }
                     });
-                    assertEquals(1, TestSSTable.countIn(directory.path()));
+                    assertThat(TestSSTable.countIn(directory.path())).isEqualTo(1);
 
                     ByteBuffer key1 = Int32Type.instance.fromString("1");
                     BigInteger token1 = BRIDGE.hash(partitioner, key1);
@@ -241,8 +238,8 @@ public class ReaderUtilsTests
                                                                                               iPartitioner,
                                                                                               descriptor,
                                                                                               Collections.singletonList(keyInSSTable));
-                        assertEquals(1, filters.size());
-                        assertEquals(keyInSSTable, filters.get(0));
+                        assertThat(filters.size()).isEqualTo(1);
+                        assertThat(filters.get(0)).isEqualTo(keyInSSTable);
                     }
                 }
                 catch (IOException exception)
@@ -270,14 +267,14 @@ public class ReaderUtilsTests
                             }
                         }
                     });
-                    assertEquals(1, TestSSTable.countIn(directory.path()));
+                    assertThat(TestSSTable.countIn(directory.path())).isEqualTo(1);
 
                     Path indexFile = TestSSTable.firstIn(directory.path(), FileType.INDEX);
                     try (InputStream indexStream = new FileInputStream(indexFile.toString()))
                     {
                         SSTable ssTable = mock(SSTable.class);
                         when(ssTable.openPrimaryIndexStream()).thenReturn(indexStream);
-                        assertFalse(ReaderUtils.anyFilterKeyInIndex(ssTable, Collections.emptyList()));
+                        assertThat(ReaderUtils.anyFilterKeyInIndex(ssTable, Collections.emptyList())).isFalse();
                     }
                 }
                 catch (IOException exception)
@@ -305,7 +302,7 @@ public class ReaderUtilsTests
                             }
                         }
                     });
-                    assertEquals(1, TestSSTable.countIn(directory.path()));
+                    assertThat(TestSSTable.countIn(directory.path())).isEqualTo(1);
 
                     ByteBuffer key = Int32Type.instance.fromString("51");
                     BigInteger token = BRIDGE.hash(partitioner, key);
@@ -316,7 +313,7 @@ public class ReaderUtilsTests
                     {
                         SSTable ssTable = mock(SSTable.class);
                         when(ssTable.openPrimaryIndexStream()).thenReturn(indexStream);
-                        assertFalse(ReaderUtils.anyFilterKeyInIndex(ssTable, Collections.singletonList(keyNotInSSTable)));
+                        assertThat(ReaderUtils.anyFilterKeyInIndex(ssTable, Collections.singletonList(keyNotInSSTable))).isFalse();
                     }
                 }
                 catch (IOException exception)
@@ -344,7 +341,7 @@ public class ReaderUtilsTests
                             }
                         }
                     });
-                    assertEquals(1, TestSSTable.countIn(directory.path()));
+                    assertThat(TestSSTable.countIn(directory.path())).isEqualTo(1);
 
                     ByteBuffer key = Int32Type.instance.fromString("19");
                     BigInteger token = BRIDGE.hash(partitioner, key);
@@ -355,7 +352,7 @@ public class ReaderUtilsTests
                     {
                         SSTable ssTable = mock(SSTable.class);
                         when(ssTable.openPrimaryIndexStream()).thenReturn(indexStream);
-                        assertTrue(ReaderUtils.anyFilterKeyInIndex(ssTable, Collections.singletonList(keyInSSTable)));
+                        assertThat(ReaderUtils.anyFilterKeyInIndex(ssTable, Collections.singletonList(keyInSSTable))).isTrue();
                     }
                 }
                 catch (IOException exception)
